@@ -25,6 +25,7 @@
 #include "nasl_func.h"
 #include "nasl_var.h"
 #include "nasl_lex_ctxt.h"
+#include "nasl_crypto2.h"
 #include "exec.h"
 
 #include <getopt.h>
@@ -39,6 +40,7 @@
 
 extern char * nasl_version();
 extern void * hg_init(char *, int);
+extern void   hg_cleanup  (void *);
 extern int hg_next_host(void*, struct in_addr*, char *, int);
 harglst * Globals;
 extern int execute_instruction(struct arglist *, char *);
