@@ -393,8 +393,7 @@ tree_cell*
 nasl_get_tmp_dir(lex_ctxt * lexic)
 {
   tree_cell	*retc;
-  char		*p, path[MAXPATHLEN];
-  int		warn = 0;
+  char		path[MAXPATHLEN];
 
  if (check_authenticated(lexic) < 0) return NULL;
  snprintf(path, sizeof(path), "%s/nessus/tmp/", NESSUS_STATE_DIR);
@@ -522,7 +521,6 @@ nasl_file_read(lex_ctxt * lexic)
 {
   tree_cell	*retc;
   char		*buf;
-  int		len;
   int		fd;
   int           flength;
   int           n;
@@ -615,7 +613,6 @@ tree_cell*
 nasl_file_seek(lex_ctxt * lexic)
 {
   tree_cell	*retc;
-  int		len;
   int		fd;
   int           foffset;
 
