@@ -847,7 +847,7 @@ int generate_signed_script(char * filename)
  {
   printf("%.2x", result[i]);
  }
- printf("\n", len);
+ printf("\n");
  memset(msg + msg_len, 0, sizeof(msg_len));
  printf("%s", msg);
  fflush(stdout);
