@@ -744,7 +744,7 @@ nasl_gettimeofday(lex_ctxt* lexic)
       nasl_perror(lexic, "gettimeofday: %s\n",  strerror(errno));
       return NULL;
     }
-  sprintf(str, "%u.%06u", t.tv_sec, t.tv_usec);
+  sprintf(str, "%u.%06u", (unsigned int)t.tv_sec, (unsigned int)t.tv_usec);
   retc = alloc_typed_cell(CONST_DATA);
   retc->size = strlen(str);
   retc->x.str_val = emalloc(retc->size);
@@ -834,15 +834,12 @@ tree_cell*
 nasl_open_sock_kdc(lex_ctxt* lexic)
 {
   tree_cell		*retc;
-  struct timeval	t;
   int                   timeout = 30;
   int                   port = 88;
   char                  *hostname = NULL; /* Domain name for windows */
   int                   tcp = 0;
   int                   ret;
-  struct arglist        *script_infos, *prefs;
-  char                  *_port = NULL, *_tcp = NULL;
-  char * val;
+  struct arglist        *script_infos;
   int type;
 
 
