@@ -1174,6 +1174,7 @@ tree_cell * nasl_tcp_ping(lex_ctxt * lexic)
  int sports[]= { 0,     0,   0,  0,  0, 1023, 0,  0,    0,    0,  0,   0,    0,    0,    0,  0,   0,   0,    0,    0, 53,   0,    0,    20,   0,  25,   0,    0, 0};
  int ports[] = { 139, 135, 445, 80, 22, 515, 23, 21, 6000, 1025, 25, 111, 1028, 9100, 1029, 79, 497, 548, 5000, 1917, 53, 161, 9001, 65535, 443, 113, 993, 8080, 0};
  int num_ports = 0;
+ int custom_port = 0;
  
  
  if( dst == NULL ) 
@@ -1203,7 +1204,10 @@ tree_cell * nasl_tcp_ping(lex_ctxt * lexic)
 
  port = get_int_local_var_by_name(lexic, "port", -1);
  if(port == -1)
+	{
 	 port = plug_get_host_open_port(script_infos);
+	 custom_port ++;
+	}
  
  if(islocalhost(dst) > 0 )src.s_addr = dst->s_addr;
   else 
@@ -1263,6 +1267,7 @@ tree_cell * nasl_tcp_ping(lex_ctxt * lexic)
  tv.tv_sec = 0;
  tv.tv_usec = 100000;
  if(bpf >= 0 && (pk = bpf_next_tv(bpf, &len, &tv)))flag++;	
+ if ( flag == 0 && custom_port != 0 ) port = plug_get_host_open_port(script_infos);
   }
  }
 
