@@ -753,7 +753,7 @@ tree_cell*
 nasl_get_source_port(lex_ctxt* lexic)
 {
   struct sockaddr_in	ia;
-  int		i, s, fd;
+  int		s, fd;
   unsigned  int	l;
   tree_cell	*retc;
   int         type;
