@@ -44,8 +44,8 @@ int str_match(const char* string, const char* pattern, int icase)
 	  while (*p ++ != '\0');
 	  return 0;
 	}
-      else if (icase && tolower(*pattern) != tolower(*string) ||
-	       ! icase && *pattern != *string)
+      else if ((icase && tolower(*pattern) != tolower(*string)) ||
+	       (!icase && *pattern != *string))
 	return 0;
       pattern ++; string ++;
     }
